# pymongal
[![TravisCIBadge](https://travis-ci.org/research-software-directory/pymongal.svg?branch=master)](https://travis-ci.org/research-software-directory/pymongal)
[![Coverage Status](https://coveralls.io/repos/github/research-software-directory/pymongal/badge.svg)](https://coveralls.io/github/research-software-directory/pymongal)

Python MongoDB Abstraction Library
